package cz.muni.fi.pa165.rest.service;

import cz.muni.fi.pa165.rest.data.CustomerResource;
import java.util.SortedMap;
import java.util.concurrent.ConcurrentSkipListMap;
import java.util.concurrent.atomic.AtomicInteger;
import org.springframework.stereotype.Service;

/**
 * Our Service class should get Customers from other application's layer
 * In this case we are instantiating all the customers and adding them to 
 * an in-memory representation
 * 
 */
@Service
public class CustomersService {
    
    private static SortedMap<Integer, CustomerResource> customerDB = new ConcurrentSkipListMap<Integer, CustomerResource>();
    private static AtomicInteger idCounter                         = new AtomicInteger(0);
    
 
    public CustomersService() {
           
        customerDB.put(idCounter.incrementAndGet(), new CustomerResource(Integer.toString(idCounter.get()), 
                "Isaac", "Newton", "Scientist", "Law of Universal Gravitation"));
        customerDB.put(idCounter.incrementAndGet(), new CustomerResource(Integer.toString(idCounter.get()), 
                "Johannes", "Gutenberg", "Inventor", "printing press"));
        customerDB.put(idCounter.incrementAndGet(), new CustomerResource(Integer.toString(idCounter.get()), 
                "Albert", "Einstein", "Scientist", "Theory of Relativity"));
        customerDB.put(idCounter.incrementAndGet(), new CustomerResource(Integer.toString(idCounter.get()), 
                "Enrico", "Fermi", "Physicist", "Development of Quantum Theory"));
        customerDB.put(idCounter.incrementAndGet(), new CustomerResource(Integer.toString(idCounter.get()), 
                "James", "Watt", "Inventor", "Steam Engine"));
        customerDB.put(idCounter.incrementAndGet(), new CustomerResource(Integer.toString(idCounter.get()), 
                "Guglielmo", "Marconi", "Inventor", "Radio"));
        customerDB.put(idCounter.incrementAndGet(), new CustomerResource(Integer.toString(idCounter.get()), 
                "Werner", "Eisenberg", "Physicist", "Quantum Mechanics"));
        
    }
 
    
    public SortedMap<Integer, CustomerResource> getCustomers(){
        return new ConcurrentSkipListMap<Integer, CustomerResource>(customerDB);
    }
    
    public CustomerResource addCustomer(CustomerResource customerResource){
       return customerDB.put(Integer.parseInt(customerResource.getId()), customerResource);
    }
    
    public CustomerResource updateCustomer(Integer id, CustomerResource customerResource){
       return customerDB.put(id, customerResource);
    }
    
     public void removeCustomer(Integer id){
       customerDB.remove(id);
    }
    
}
